---
title: 법인카드로 결제할 수 있나요?
category: 자주 묻는 질문 (일반 문의) > 결제서비스 > 결제서비스
seo:
  title: 법인카드 결제 가능 여부
  description: >-
    결제 시 개인카드와 법인카드를 나누거나, 법인카드를 위한 별도의 결제방식이 존재하지는 않습니다. 포트원이 안내하는 일반 인증결제 및
    비인증 결제 이용시마다 다른 법인카드 결제 가능 여부를 확인해보세요.
  keywords:
    - 일반결제
tags:
  - 공통
  - 일반결제
pgCompanies:
  - 공통
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="법인카드로 온라인결제 시도시 참고사항을 안내드립니다. 
법인카드는 결제대행사 및 카드사에서 허용하거나 제한하는 별도의 정책이 있진 않으므로 
결제자가 어떤 인증 방식을 사용할지에 따라 가능여부가 달라질 수 있습니다." />

### **일반 인증결제 이용시**

포트원의 일반결제는 \[카드, 계좌이체, 가상 계좌, 휴대폰 소액결제]의 수단을 기본으로 하는인증 절차가 존재하는 결제방식입니다. 인증 절차가 존재하는 결제방식일 경우에는 법인카드도 동일한 인증 절차를 거쳐야 하므로

1. **카드사 앱카드 결제가 가능한지 확인**

결제자가 시도하는 PC, 모바일환경에서 카드사에서 요구하는 앱카드 인증등이 가능한지 확인합니다. \
법인카드로 카드사 인증이 가능하다면 결제가 가능합니다.

2\. **카드사의 일반결제 방식을 이용**

일부 카드사는 카드사 결제화면 내에서 카드번호와 CVC번호만으로 결제가 가능한 일반결제 방식을 제공합니다. \
실물 카드를 갖고 계시거나 카드번호 정보를 알고 계신 경우 결제가 가능합니다.

카드사에서 요구하는 인증방식은 카드사별로 상이하며 카드사 심사 결과에 따라 달라질 수도 있는 점 참고부탁드립니다.



### **수기결제 이용시**

인증 과정을 거쳐 결제가 어렵고 단건으로 결제가 되어야 하는 경우라면 카드 정보 기입만으로도 결제가 가능한 비인증 결제 방식 중 '수기결제'를 선택해 주셔야 합니다.

수기결제는 카드 정보(카드번호, 유효기간, 사업자 번호(혹은 생년월일), 비밀번호 앞 2자리) 입력만으로 결제가 가능한 일회성(단건) 결제방식입니다. API 호출 방식으로 지원 가능하므로 카드 정보를 받는 UI는 가맹점에서 직접 구현해 주셔야 하는 점을 참고해주시기 바랍니다.

### **정기결제 이용시**

정기결제는 결제대행사의 결제창을 띄우는 방식과 API를 호출하는 방식으로 구분됩니다.

결제대행사의 결제창을 띄우는 방식은 \[카드번호+유효기간+사업자번호/생년월일+비밀번호 앞2자리] 를 입력하여 결제를 진행하며 일부 결제대행사에서는 공인인증서(혹은 본인인증)을 요구하기도 하므로 결제자의 카드가 공인(본인)인증이 가능한지 확인하신 후 결제를 진행해주시기 바랍니다.

API 방식은 \[카드번호+유효기간+사업자번호/생년월일+비밀번호 앞2자리]를 입력하고 API로 호출하기 때문에 별도 인증과정 없이 결제가 가능합니다.

<Callout title="정기결제시 공인인증 필수여부 보러가기↗" />
